#
# spec file for package argocd-autopilot
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           argocd-autopilot
Version:        0.4.19
Release:        1.1
Summary:        Opinionated way of installing Argo-CD
License:        Apache-2.0
URL:            https://github.com/argoproj-labs/argocd-autopilot
Source:         argocd-autopilot-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
New users to GitOps and Argo CD are not often sure how they should structure
their repos, add applications, promote apps across environments, and manage the
Argo CD installation itself using GitOps.

Argo CD Autopilot saves operators time by:
* Installing and managing the Argo CD application using GitOps.
* Providing a clear structure for how applications are to be added and updated,
  all from git.
* Creating a simple pattern for making updates to applications and promoting
  those changes across environments.
* Enabling better disaster recovery by being able to bootstrap new clusters
  with all the applications previously installed.
* Handling secrets for Argo CD to prevent them from spilling into plaintext
  git. (Soon to come)

The Argo-CD Autopilot is a tool which offers an opinionated way of installing
Argo-CD and managing GitOps repositories.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortended by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

INSTALLATION_MANIFESTS_URL="github.com/argoproj-labs/argocd-autopilot/manifests/base?ref=v%{version}"
INSTALLATION_MANIFESTS_NAMESPACED_URL=""

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
    -X 'github.com/argoproj-labs/argocd-autopilot/pkg/store.binaryName=%{name}' \
    -X 'github.com/argoproj-labs/argocd-autopilot/pkg/store.version=%{version}' \
    -X 'github.com/argoproj-labs/argocd-autopilot/pkg/store.buildDate=${BUILD_DATE}' \
    -X 'github.com/argoproj-labs/argocd-autopilot/pkg/store.gitCommit=${COMMIT_HASH:0:8}' \
    -X 'github.com/argoproj-labs/argocd-autopilot/pkg/store.installationManifestsURL=${INSTALLATION_MANIFESTS_URL}' \
    -X 'github.com/argoproj-labs/argocd-autopilot/pkg/store.installationManifestsNamespacedURL=${INSTALLATION_MANIFESTS_NAMESPACED_URL}'" \
   -o bin/argocd-autopilot ./cmd/

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.4.19:
  * chore: update version to v0.4.19 and release notes
  * feat: add cluster-only uninstall option and resource deletion
    handling (#634)
  * Fix-vulns (#635)
  * release-v0.4.18 (#556)
* Wed Nov 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.18:
  * updated changelog
  * fixed `project create` help text
  * created new release
  * Sec-fixes (#598)
  * add sudo command for linux installation (#589)
  * fix bootstrap for Azure DevOps (#594)
  * fix clone repo from azure (#595)
  * updated golang to 1.22 (#555)
  * Bump github.com/ktrysmt/go-bitbucket from 0.9.73 to 0.9.75
    (#553)
  * Bump github.com/xanzy/go-gitlab from 0.95.2 to 0.97.0 (#552)
  * bump argo-cd to `v2.10.0` (#554)
  * Bump github.com/cloudflare/circl from 1.3.3 to 1.3.7 (#546)
  * Bump code.gitea.io/sdk/gitea from 0.17.0 to 0.17.1 (#544)
  * Bump github.com/spf13/viper from 1.18.1 to 1.18.2 (#543)
  * Bump golang.org/x/crypto from 0.16.0 to 0.17.0 (#542)
  * Bump github.com/ktrysmt/go-bitbucket from 0.9.72 to 0.9.73
    (#540)
  * Bump github.com/xanzy/go-gitlab from 0.94.0 to 0.95.2 (#541)
  * Bump github.com/go-git/go-git/v5 from 5.10.1 to 5.11.0 (#539)
  * Bump github.com/spf13/viper from 1.17.0 to 1.18.1 (#537)
  * Bump code.gitea.io/sdk/gitea from 0.16.0 to 0.17.0 (#532)
  * Bump github.com/go-git/go-git/v5 from 5.10.0 to 5.10.1 (#531)
  * Bump github.com/go-jose/go-jose/v3 from 3.0.0 to 3.0.1 (#528)
  * Bump github.com/xanzy/go-gitlab from 0.93.2 to 0.94.0 (#526)
  * Bump github.com/ktrysmt/go-bitbucket from 0.9.71 to 0.9.72
    (#527)
  * Bump
    go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc
    (#525)
  * Bump github.com/ktrysmt/go-bitbucket from 0.9.70 to 0.9.71
    (#524)
  * Bump github.com/spf13/cobra from 1.7.0 to 1.8.0 (#523)
  * Bump github.com/xanzy/go-gitlab from 0.93.1 to 0.93.2 (#518)
  * Bump github.com/go-git/go-git/v5 from 5.9.0 to 5.10.0 (#519)
  * Release v0.4.17 (#515)
* Tue Mar 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.4.17:
  * skip `snyk test`, only test image
  * updated changelog and release_notes
  * updated makefile to `v0.4.17`
  * Bump github.com/spf13/viper from 1.16.0 to 1.17.0 (#511)
  * Bump github.com/ktrysmt/go-bitbucket from 0.9.68 to 0.9.70 (#514)
  * Bump github.com/xanzy/go-gitlab from 0.92.1 to 0.93.1 (#512)
  * Update dependencies (#513)
  * Bump github.com/xanzy/go-gitlab from 0.91.1 to 0.92.1 (#508)
  * Bump github.com/ktrysmt/go-bitbucket from 0.9.67 to 0.9.68 (#506)
  * Bump github.com/argoproj/argo-cd/v2 from 2.8.3 to 2.8.4 (#504)
* Tue Mar 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package argocd-autopilot: opinionated tool to install ArgoCD
